@@ -15,7 +15,7 @@ use crate::{
     error::Result,
     pipeline::name::QueueName,
     sql_processor::SqlProcessor,
-    stream_engine::{command::Command, SinkRow, SqlConvertible, SqlValue},
+    stream_engine::{command::Command, SinkRow, SpringValue, SqlValue},
 };
 
 use self::engine_mutex::EngineMutex;
@@ -44,7 +44,7 @@ pub struct SpringPipeline {
 
 /// Row object from an in memory queue.
 #[derive(Debug)]
-pub struct SpringRow(SinkRow);
+pub struct SpringRow(pub(in crate::api) SinkRow);
 
 impl From<SinkRow> for SpringRow {
     fn from(sink_row: SinkRow) -> Self {
@@ -119,7 +119,7 @@ pub fn spring_column_text(row: &SpringRow, i_col: usize) -> Result<String> {
     spring_column(row, i_col)
 }
 
-fn spring_column<T: SqlConvertible>(row: &SpringRow, i_col: usize) -> Result<T> {
+fn spring_column<T: SpringValue>(row: &SpringRow, i_col: usize) -> Result<T> {
     let v = row.0.get_by_index(i_col)?;
     if let SqlValue::NotNull(v) = v {
         v.unpack()
