@@ -2,8 +2,6 @@
 
 pub(crate) mod sink_writer_type;
 
-use serde::{Deserialize, Serialize};
-
 use self::sink_writer_type::SinkWriterType;
 
 use super::{
@@ -11,11 +9,11 @@ use super::{
     option::Options,
 };
 
-#[derive(Clone, PartialEq, Eq, Debug, Serialize, Deserialize, new)]
+#[derive(Clone, PartialEq, Eq, Debug, new)]
 pub(crate) struct SinkWriterModel {
     name: SinkWriterName,
     sink_writer_type: SinkWriterType,
-    from_sink_stream: StreamName,
+    sink_upstream: StreamName,
     options: Options,
 }
 
@@ -28,8 +26,8 @@ impl SinkWriterModel {
         &self.sink_writer_type
     }
 
-    pub(crate) fn from_sink_stream(&self) -> &StreamName {
-        &self.from_sink_stream
+    pub(crate) fn sink_upstream(&self) -> &StreamName {
+        &self.sink_upstream
     }
 
     pub(crate) fn options(&self) -> &Options {
