@@ -4,22 +4,24 @@ use crate::{
     error::Result,
     stream_engine::{
         autonomous_executor::row::value::sql_value::nn_sql_value::NnSqlValue,
-        time::timestamp::Timestamp,
+        time::timestamp::SpringTimestamp,
     },
 };
 
-use super::SqlConvertible;
-
-impl SqlConvertible for String {
-    fn into_sql_value(self) -> NnSqlValue {
-        NnSqlValue::Text(self)
-    }
+use super::{SpringValue, ToNnSqlValue};
 
+impl SpringValue for String {
     fn try_from_string(v: &str) -> Result<Self> {
         Ok(v.to_string())
     }
 
-    fn try_from_timestamp(v: &Timestamp) -> Result<Self> {
+    fn try_from_timestamp(v: &SpringTimestamp) -> Result<Self> {
         Ok(v.to_string())
     }
 }
+
+impl ToNnSqlValue for String {
+    fn into_sql_value(self) -> NnSqlValue {
+        NnSqlValue::Text(self)
+    }
+}
