@@ -3,8 +3,8 @@
 use std::cmp::max;
 
 use crate::stream_engine::time::{
-    duration::{event_duration::EventDuration, SpringDuration},
-    timestamp::{Timestamp, MIN_TIMESTAMP},
+    duration::{event_duration::SpringEventDuration, SpringDuration},
+    timestamp::{SpringTimestamp, MIN_TIMESTAMP},
 };
 
 /// A watermark is held by each window.
@@ -14,23 +14,23 @@ use crate::stream_engine::time::{
 /// ```
 #[derive(Copy, Clone, Eq, PartialEq, Ord, PartialOrd, Debug)]
 pub(in crate::stream_engine::autonomous_executor) struct Watermark {
-    max_rowtime: Timestamp,
-    allowed_delay: EventDuration,
+    max_rowtime: SpringTimestamp,
+    allowed_delay: SpringEventDuration,
 }
 
 impl Watermark {
-    pub(in crate::stream_engine::autonomous_executor) fn new(allowed_delay: EventDuration) -> Self {
+    pub(in crate::stream_engine::autonomous_executor) fn new(allowed_delay: SpringEventDuration) -> Self {
         Self {
             max_rowtime: MIN_TIMESTAMP + allowed_delay.to_chrono(), // to avoid overflow
             allowed_delay,
         }
     }
 
-    pub(in crate::stream_engine::autonomous_executor) fn as_timestamp(&self) -> Timestamp {
+    pub(in crate::stream_engine::autonomous_executor) fn as_timestamp(&self) -> SpringTimestamp {
         self.max_rowtime - self.allowed_delay.to_chrono()
     }
 
-    pub(in crate::stream_engine::autonomous_executor) fn update(&mut self, rowtime: Timestamp) {
+    pub(in crate::stream_engine::autonomous_executor) fn update(&mut self, rowtime: SpringTimestamp) {
         self.max_rowtime = max(rowtime, self.max_rowtime);
     }
 }
