@@ -5,7 +5,10 @@ mod generic_worker_scheduler;
 use std::sync::Arc;
 
 use crate::stream_engine::autonomous_executor::{
-    event_queue::{event::EventTag, EventQueue},
+    event_queue::{
+        event::{BlockingEventTag, EventTag, NonBlockingEventTag},
+        non_blocking_event_queue::NonBlockingEventQueue,
+    },
     memory_state_machine::{MemoryState, MemoryStateTransition},
     performance_metrics::{
         metrics_update_command::metrics_update_by_task_execution::MetricsUpdateByTaskExecutionOrPurge,
@@ -15,7 +18,7 @@ use crate::stream_engine::autonomous_executor::{
     task_executor::task_worker_thread_handler::{
         TaskWorkerLoopState, TaskWorkerThreadArg, TaskWorkerThreadHandler,
     },
-    worker::worker_thread::WorkerThread,
+    worker::{worker_handle::WorkerSetupCoordinator, worker_thread::WorkerThread},
 };
 
 use self::generic_worker_scheduler::GenericWorkerScheduler;
@@ -31,18 +34,22 @@ impl WorkerThread for GenericWorkerThread {
 
     type LoopState = TaskWorkerLoopState<GenericWorkerScheduler>;
 
+    fn setup_ready(worker_setup_coordinator: Arc<WorkerSetupCoordinator>) {
+        worker_setup_coordinator.ready_generic_worker()
+    }
+
     fn event_subscription() -> Vec<EventTag> {
         vec![
-            EventTag::UpdatePipeline,
-            EventTag::ReplacePerformanceMetrics,
-            EventTag::TransitMemoryState,
+            EventTag::Blocking(BlockingEventTag::UpdatePipeline),
+            EventTag::NonBlocking(NonBlockingEventTag::ReplacePerformanceMetrics),
+            EventTag::NonBlocking(NonBlockingEventTag::TransitMemoryState),
         ]
     }
 
     fn main_loop_cycle(
         current_state: Self::LoopState, // generic worker's loop cycle does not mutate state (while event handlers do)
         thread_arg: &Self::ThreadArg,
-        event_queue: &EventQueue,
+        event_queue: &NonBlockingEventQueue,
     ) -> Self::LoopState {
         TaskWorkerThreadHandler::main_loop_cycle::<GenericWorkerScheduler>(
             current_state,
@@ -55,7 +62,7 @@ impl WorkerThread for GenericWorkerThread {
         current_state: Self::LoopState,
         pipeline_derivatives: Arc<PipelineDerivatives>,
         thread_arg: &Self::ThreadArg,
-        _event_queue: Arc<EventQueue>,
+        _event_queue: Arc<NonBlockingEventQueue>,
     ) -> Self::LoopState {
         log::debug!(
             "[GenericWorker#{}] got UpdatePipeline event",
@@ -71,7 +78,7 @@ impl WorkerThread for GenericWorkerThread {
         current_state: Self::LoopState,
         metrics: Arc<PerformanceMetrics>,
         thread_arg: &Self::ThreadArg,
-        _event_queue: Arc<EventQueue>,
+        _event_queue: Arc<NonBlockingEventQueue>,
     ) -> Self::LoopState {
         log::debug!(
             "[GenericWorker#{}] got ReplacePerformanceMetrics event",
@@ -87,7 +94,7 @@ impl WorkerThread for GenericWorkerThread {
         current_state: Self::LoopState,
         memory_state_transition: Arc<MemoryStateTransition>,
         thread_arg: &Self::ThreadArg,
-        _event_queue: Arc<EventQueue>,
+        _event_queue: Arc<NonBlockingEventQueue>,
     ) -> Self::LoopState {
         let mut state = current_state;
 
@@ -119,7 +126,7 @@ impl WorkerThread for GenericWorkerThread {
         _current_state: Self::LoopState,
         _metrics: Arc<MetricsUpdateByTaskExecutionOrPurge>,
         _thread_arg: &Self::ThreadArg,
-        _event_queue: Arc<EventQueue>,
+        _event_queue: Arc<NonBlockingEventQueue>,
     ) -> Self::LoopState {
         unreachable!()
     }
@@ -128,7 +135,7 @@ impl WorkerThread for GenericWorkerThread {
         _current_state: Self::LoopState,
         _metrics_summary: Arc<PerformanceMetricsSummary>,
         _thread_arg: &Self::ThreadArg,
-        _event_queue: Arc<EventQueue>,
+        _event_queue: Arc<NonBlockingEventQueue>,
     ) -> Self::LoopState {
         unreachable!()
     }
