@@ -22,8 +22,7 @@ fn test_feat_add_mul_integer() {
     });
     let source_input = vec![json1];
 
-    let test_source =
-        ForeignSource::start(ForeignSourceInput::new_fifo_batch(source_input)).unwrap();
+    let test_source = ForeignSource::new().unwrap();
     let test_sink = ForeignSink::start().unwrap();
 
     let ddls = vec![
@@ -74,6 +73,7 @@ fn test_feat_add_mul_integer() {
     ];
 
     let _pipeline = apply_ddls(&ddls, spring_config_default());
+    test_source.start(ForeignSourceInput::new_fifo_batch(source_input));
     let sink_received = drain_from_sink(&test_sink);
     let r = sink_received.get(0).unwrap();
 
@@ -90,8 +90,7 @@ fn test_feat_add_mul_float() {
     });
     let source_input = vec![json1];
 
-    let test_source =
-        ForeignSource::start(ForeignSourceInput::new_fifo_batch(source_input)).unwrap();
+    let test_source = ForeignSource::new().unwrap();
     let test_sink = ForeignSink::start().unwrap();
 
     let ddls = vec![
@@ -142,6 +141,7 @@ fn test_feat_add_mul_float() {
     ];
 
     let _pipeline = apply_ddls(&ddls, spring_config_default());
+    test_source.start(ForeignSourceInput::new_fifo_batch(source_input));
     let sink_received = drain_from_sink(&test_sink);
     let r = sink_received.get(0).unwrap();
 
